"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.administration.v0.environments.configuration_pb2
import qwak.administration.v0.environments.environment_pb2
import qwak.administration.v0.environments.personalization_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateEnvironmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    PERSONALIZATION_FIELD_NUMBER: builtins.int
    environment_name: builtins.str
    """Environment name to be created. For example - Dev, Prod, and QA."""
    tenant_id: builtins.str
    """The tenant ID the environment is configured for (changed to be account id)"""
    account_id: builtins.str
    """The account ID the environment is configured for"""
    cluster_id: builtins.str
    """The Qwak Cluster the environment will deploy in."""
    @property
    def configuration(self) -> qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration:
        """Environment configuration"""
    @property
    def personalization(self) -> qwak.administration.v0.environments.personalization_pb2.EnvironmentPersonalization:
        """Environment personalization"""
    def __init__(
        self,
        *,
        environment_name: builtins.str = ...,
        tenant_id: builtins.str = ...,
        account_id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        configuration: qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration | None = ...,
        personalization: qwak.administration.v0.environments.personalization_pb2.EnvironmentPersonalization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "personalization", b"personalization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "cluster_id", b"cluster_id", "configuration", b"configuration", "environment_name", b"environment_name", "personalization", b"personalization", "tenant_id", b"tenant_id"]) -> None: ...

global___CreateEnvironmentRequest = CreateEnvironmentRequest

class CreateEnvironmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def environment(self) -> qwak.administration.v0.environments.environment_pb2.QwakEnvironment:
        """Created environment"""
    def __init__(
        self,
        *,
        environment: qwak.administration.v0.environments.environment_pb2.QwakEnvironment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> None: ...

global___CreateEnvironmentResponse = CreateEnvironmentResponse

class UpdateEnvironmentConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id to update"""
    @property
    def configuration(self) -> qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration:
        """New environment configuration"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        configuration: qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "environment_id", b"environment_id"]) -> None: ...

global___UpdateEnvironmentConfigurationRequest = UpdateEnvironmentConfigurationRequest

class UpdateEnvironmentConfigurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateEnvironmentConfigurationResponse = UpdateEnvironmentConfigurationResponse

class UpdateEnvironmentPersonalizationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    PERSONALIZATION_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id to update"""
    @property
    def personalization(self) -> qwak.administration.v0.environments.personalization_pb2.EnvironmentPersonalization:
        """New environment configuration"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        personalization: qwak.administration.v0.environments.personalization_pb2.EnvironmentPersonalization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["personalization", b"personalization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "personalization", b"personalization"]) -> None: ...

global___UpdateEnvironmentPersonalizationRequest = UpdateEnvironmentPersonalizationRequest

class UpdateEnvironmentPersonalizationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateEnvironmentPersonalizationResponse = UpdateEnvironmentPersonalizationResponse

class GetEnvironmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment ID to fetch"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetEnvironmentRequest = GetEnvironmentRequest

class GetEnvironmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def environment(self) -> qwak.administration.v0.environments.environment_pb2.QwakEnvironment:
        """Fetched Environment by the requested ID"""
    def __init__(
        self,
        *,
        environment: qwak.administration.v0.environments.environment_pb2.QwakEnvironment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> None: ...

global___GetEnvironmentResponse = GetEnvironmentResponse

class GetEnvironmentApplicationUserCredentialsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment ID to fetch"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetEnvironmentApplicationUserCredentialsRequest = GetEnvironmentApplicationUserCredentialsRequest

class GetEnvironmentApplicationUserCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def credentials(self) -> qwak.administration.v0.environments.environment_pb2.EnvironmentApplicationUserCredentials:
        """The API key for the application user of the requested environment"""
    def __init__(
        self,
        *,
        credentials: qwak.administration.v0.environments.environment_pb2.EnvironmentApplicationUserCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials"]) -> None: ...

global___GetEnvironmentApplicationUserCredentialsResponse = GetEnvironmentApplicationUserCredentialsResponse

class SetEnvironmentApplicationUserCredentialsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment ID to fetch"""
    @property
    def credentials(self) -> qwak.administration.v0.environments.environment_pb2.EnvironmentApplicationUserCredentials:
        """The API key for the application user of the requested environment"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        credentials: qwak.administration.v0.environments.environment_pb2.EnvironmentApplicationUserCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "environment_id", b"environment_id"]) -> None: ...

global___SetEnvironmentApplicationUserCredentialsRequest = SetEnvironmentApplicationUserCredentialsRequest

class SetEnvironmentApplicationUserCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetEnvironmentApplicationUserCredentialsResponse = SetEnvironmentApplicationUserCredentialsResponse

class ListEnvironmentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Filter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENVIRONMENT_STATUS_FIELD_NUMBER: builtins.int
        environment_status: qwak.administration.v0.environments.environment_pb2.QwakEnvironmentStatus.ValueType
        """Filter based on environment status"""
        def __init__(
            self,
            *,
            environment_status: qwak.administration.v0.environments.environment_pb2.QwakEnvironmentStatus.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["environment_status", b"environment_status"]) -> None: ...

    FILTER_FIELD_NUMBER: builtins.int
    @property
    def filter(self) -> global___ListEnvironmentsRequest.Filter: ...
    def __init__(
        self,
        *,
        filter: global___ListEnvironmentsRequest.Filter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> None: ...

global___ListEnvironmentsRequest = ListEnvironmentsRequest

class ListEnvironmentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENTS_FIELD_NUMBER: builtins.int
    @property
    def environments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.administration.v0.environments.environment_pb2.QwakEnvironment]:
        """All environments that matched the provided filter"""
    def __init__(
        self,
        *,
        environments: collections.abc.Iterable[qwak.administration.v0.environments.environment_pb2.QwakEnvironment] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environments", b"environments"]) -> None: ...

global___ListEnvironmentsResponse = ListEnvironmentsResponse



from _qwak_proto.qwak.inference.feedback.feedback_pb2 import (
    ActualValuesRequest,
    ActualValuesResponse,
    ConfigureFeedbackRequest,
    ConfigureFeedbackResponse,
)
from _qwak_proto.qwak.inference.feedback.feedback_pb2_grpc import (
    FeedbackServiceServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class FeedbackServiceMock(FeedbackServiceServicer):
    def __init__(self):
        super(FeedbackServiceMock, self).__init__()

    def PostFeedback(
        self, request: ActualValuesRequest, context
    ) -> ActualValuesResponse:
        try:
            return ActualValuesResponse(status=ActualValuesResponse.ValueStatus.SUCCESS)
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def ConfigureFeedback(
        self, request: ConfigureFeedbackRequest, context
    ) -> ConfigureFeedbackResponse:
        try:
            return ConfigureFeedbackResponse(
                status=ConfigureFeedbackResponse.ValueStatus.SUCCESS
            )
        except Exception as e:
            raise_internal_grpc_error(context, e)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fqwak/automation/v1/common.proto\x12\x12qwak.automation.v1\"G\n\x06Metric\x12\x33\n\nsql_metric\x18\x01 \x01(\x0b\x32\x1d.qwak.automation.v1.SqlMetricH\x00\x42\x08\n\x06metric\"\x1e\n\tSqlMetric\x12\x11\n\tsql_query\x18\x01 \x01(\t*\x84\x01\n\x18MetricThresholdDirection\x12\x1c\n\x18INVALID_METRIC_DIRECTION\x10\x00\x12\t\n\x05\x42\x45LOW\x10\x01\x12\t\n\x05\x41\x42OVE\x10\x02\x12\n\n\x06\x45QUALS\x10\x03\x12\x13\n\x0f\x42\x45LOW_OR_EQUALS\x10\x04\x12\x13\n\x0f\x41\x42OVE_OR_EQUALS\x10\x05\x42!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_METRICTHRESHOLDDIRECTION = DESCRIPTOR.enum_types_by_name['MetricThresholdDirection']
MetricThresholdDirection = enum_type_wrapper.EnumTypeWrapper(_METRICTHRESHOLDDIRECTION)
INVALID_METRIC_DIRECTION = 0
BELOW = 1
ABOVE = 2
EQUALS = 3
BELOW_OR_EQUALS = 4
ABOVE_OR_EQUALS = 5


_METRIC = DESCRIPTOR.message_types_by_name['Metric']
_SQLMETRIC = DESCRIPTOR.message_types_by_name['SqlMetric']
Metric = _reflection.GeneratedProtocolMessageType('Metric', (_message.Message,), {
  'DESCRIPTOR' : _METRIC,
  '__module__' : 'qwak.automation.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.Metric)
  })
_sym_db.RegisterMessage(Metric)

SqlMetric = _reflection.GeneratedProtocolMessageType('SqlMetric', (_message.Message,), {
  'DESCRIPTOR' : _SQLMETRIC,
  '__module__' : 'qwak.automation.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.SqlMetric)
  })
_sym_db.RegisterMessage(SqlMetric)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _METRICTHRESHOLDDIRECTION._serialized_start=161
  _METRICTHRESHOLDDIRECTION._serialized_end=293
  _METRIC._serialized_start=55
  _METRIC._serialized_end=126
  _SQLMETRIC._serialized_start=128
  _SQLMETRIC._serialized_end=158
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from enum import Enum
from typing import Optional

from _qwak_proto.qwak.feature_store.sinks.sink_pb2 import (
    KafkaSink as ProtoKafkaSink,
    StreamingSink as ProtoStreamingSink,
)
from _qwak_proto.qwak.feature_store.sources.streaming_pb2 import (
    MessageFormat as ProtoMessageFormat,
)
from qwak.exceptions import QwakException
from qwak.feature_store.data_sources.streaming.kafka.authentication import (
    BaseAuthentication,
)
from qwak.feature_store.sinks.base import BaseSink
from qwak.feature_store.sinks.streaming.attachment import StreamingAttachmentPoint


class MessageFormat(Enum):
    JSON = ProtoMessageFormat.JSON


@dataclass
class KafkaSink(BaseSink):
    topic: str
    bootstrap_servers: str
    message_format: MessageFormat
    auth_configuration: BaseAuthentication
    attachment_point: Optional[StreamingAttachmentPoint]

    def _to_proto_kafka_sink(self) -> ProtoKafkaSink:
        return ProtoKafkaSink(
            topic=self.topic,
            bootstrap_servers=self.bootstrap_servers,
            message_format=self.message_format.value,
            auth_config=self.auth_configuration._to_proto(),
        )

    def to_proto_streaming_sink(self) -> ProtoStreamingSink:
        if self.attachment_point is None:
            raise QwakException(
                "A Sink must have an attachment point configured in order for it to be used as a streaming sink"
            )

        proto_kafka_sink: ProtoKafkaSink = self._to_proto_kafka_sink()

        return ProtoStreamingSink(
            name=self.name,
            kafka_sink=proto_kafka_sink,
            attachment_point=self.attachment_point._to_proto(),
        )

    def __post_init__(self):
        super().__post_init__()
        self._validate()

    def _validate(self):
        pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/automation_management_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.automation.v1 import automation_pb2 as qwak_dot_automation_dot_v1_dot_automation__pb2
from _qwak_proto.qwak.automation.v1 import automation_execution_pb2 as qwak_dot_automation_dot_v1_dot_automation__execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/automation/v1/automation_management_service.proto\x12\x12qwak.automation.v1\x1a#qwak/automation/v1/automation.proto\x1a-qwak/automation/v1/automation_execution.proto\"V\n\x17\x43reateAutomationRequest\x12;\n\x0f\x61utomation_spec\x18\x01 \x01(\x0b\x32\".qwak.automation.v1.AutomationSpec\"1\n\x18\x43reateAutomationResponse\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"m\n\x17UpdateAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12;\n\x0f\x61utomation_spec\x18\x02 \x01(\x0b\x32\".qwak.automation.v1.AutomationSpec\"\x1a\n\x18UpdateAutomationResponse\"0\n\x17\x44\x65leteAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteAutomationResponse\"*\n\x16ListAutomationsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"N\n\x17ListAutomationsResponse\x12\x33\n\x0b\x61utomations\x18\x01 \x03(\x0b\x32\x1e.qwak.automation.v1.Automation\"-\n\x14GetAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"K\n\x15GetAutomationResponse\x12\x32\n\nautomation\x18\x01 \x01(\x0b\x32\x1e.qwak.automation.v1.Automation\"5\n\x1aGetAutomationByNameRequest\x12\x17\n\x0f\x61utomation_name\x18\x01 \x01(\t\"Q\n\x1bGetAutomationByNameResponse\x12\x32\n\nautomation\x18\x01 \x01(\x0b\x32\x1e.qwak.automation.v1.Automation\"k\n\x1fListAutomationExecutionsRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x31\n\ndate_range\x18\x02 \x01(\x0b\x32\x1d.qwak.automation.v1.DateRange\"q\n ListAutomationExecutionsResponse\x12M\n\x15\x61utomation_executions\x18\x01 \x03(\x0b\x32..qwak.automation.v1.AutomationExecutionMessage\"7\n#ListLastAutomationExecutionsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\xbe\x02\n$ListLastAutomationExecutionsResponse\x12\x97\x01\n*last_automation_execution_by_automation_id\x18\x01 \x03(\x0b\x32\x63.qwak.automation.v1.ListLastAutomationExecutionsResponse.LastAutomationExecutionByAutomationIdEntry\x1a|\n*LastAutomationExecutionByAutomationIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qwak.automation.v1.AutomationExecutionMessage:\x02\x38\x01\"Q\n\"RegisterAutomationExecutionRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\"%\n#RegisterAutomationExecutionResponse\"}\n UpdateAutomationExecutionRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x43\n\x0brun_details\x18\x02 \x01(\x0b\x32..qwak.automation.v1.ExecutionRunDetailsMessage\"#\n!UpdateAutomationExecutionResponse\"L\n\x1fToggleAutomationActivityRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\"\"\n ToggleAutomationActivityResponse\"-\n\x14RunAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"\x17\n\x15RunAutomationResponse2\xda\x0b\n\x1b\x41utomationManagementService\x12m\n\x10\x43reateAutomation\x12+.qwak.automation.v1.CreateAutomationRequest\x1a,.qwak.automation.v1.CreateAutomationResponse\x12m\n\x10UpdateAutomation\x12+.qwak.automation.v1.UpdateAutomationRequest\x1a,.qwak.automation.v1.UpdateAutomationResponse\x12m\n\x10\x44\x65leteAutomation\x12+.qwak.automation.v1.DeleteAutomationRequest\x1a,.qwak.automation.v1.DeleteAutomationResponse\x12\x64\n\rGetAutomation\x12(.qwak.automation.v1.GetAutomationRequest\x1a).qwak.automation.v1.GetAutomationResponse\x12v\n\x13GetAutomationByName\x12..qwak.automation.v1.GetAutomationByNameRequest\x1a/.qwak.automation.v1.GetAutomationByNameResponse\x12j\n\x0fListAutomations\x12*.qwak.automation.v1.ListAutomationsRequest\x1a+.qwak.automation.v1.ListAutomationsResponse\x12\x85\x01\n\x18ListAutomationExecutions\x12\x33.qwak.automation.v1.ListAutomationExecutionsRequest\x1a\x34.qwak.automation.v1.ListAutomationExecutionsResponse\x12\x91\x01\n\x1cListLastAutomationExecutions\x12\x37.qwak.automation.v1.ListLastAutomationExecutionsRequest\x1a\x38.qwak.automation.v1.ListLastAutomationExecutionsResponse\x12\x8e\x01\n\x1bRegisterAutomationExecution\x12\x36.qwak.automation.v1.RegisterAutomationExecutionRequest\x1a\x37.qwak.automation.v1.RegisterAutomationExecutionResponse\x12\x88\x01\n\x19UpdateAutomationExecution\x12\x34.qwak.automation.v1.UpdateAutomationExecutionRequest\x1a\x35.qwak.automation.v1.UpdateAutomationExecutionResponse\x12\x85\x01\n\x18ToggleAutomationActivity\x12\x33.qwak.automation.v1.ToggleAutomationActivityRequest\x1a\x34.qwak.automation.v1.ToggleAutomationActivityResponse\x12\x64\n\rRunAutomation\x12(.qwak.automation.v1.RunAutomationRequest\x1a).qwak.automation.v1.RunAutomationResponseB!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')



_CREATEAUTOMATIONREQUEST = DESCRIPTOR.message_types_by_name['CreateAutomationRequest']
_CREATEAUTOMATIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateAutomationResponse']
_UPDATEAUTOMATIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateAutomationRequest']
_UPDATEAUTOMATIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAutomationResponse']
_DELETEAUTOMATIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteAutomationRequest']
_DELETEAUTOMATIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteAutomationResponse']
_LISTAUTOMATIONSREQUEST = DESCRIPTOR.message_types_by_name['ListAutomationsRequest']
_LISTAUTOMATIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListAutomationsResponse']
_GETAUTOMATIONREQUEST = DESCRIPTOR.message_types_by_name['GetAutomationRequest']
_GETAUTOMATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetAutomationResponse']
_GETAUTOMATIONBYNAMEREQUEST = DESCRIPTOR.message_types_by_name['GetAutomationByNameRequest']
_GETAUTOMATIONBYNAMERESPONSE = DESCRIPTOR.message_types_by_name['GetAutomationByNameResponse']
_LISTAUTOMATIONEXECUTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListAutomationExecutionsRequest']
_LISTAUTOMATIONEXECUTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListAutomationExecutionsResponse']
_LISTLASTAUTOMATIONEXECUTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListLastAutomationExecutionsRequest']
_LISTLASTAUTOMATIONEXECUTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListLastAutomationExecutionsResponse']
_LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY = _LISTLASTAUTOMATIONEXECUTIONSRESPONSE.nested_types_by_name['LastAutomationExecutionByAutomationIdEntry']
_REGISTERAUTOMATIONEXECUTIONREQUEST = DESCRIPTOR.message_types_by_name['RegisterAutomationExecutionRequest']
_REGISTERAUTOMATIONEXECUTIONRESPONSE = DESCRIPTOR.message_types_by_name['RegisterAutomationExecutionResponse']
_UPDATEAUTOMATIONEXECUTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateAutomationExecutionRequest']
_UPDATEAUTOMATIONEXECUTIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAutomationExecutionResponse']
_TOGGLEAUTOMATIONACTIVITYREQUEST = DESCRIPTOR.message_types_by_name['ToggleAutomationActivityRequest']
_TOGGLEAUTOMATIONACTIVITYRESPONSE = DESCRIPTOR.message_types_by_name['ToggleAutomationActivityResponse']
_RUNAUTOMATIONREQUEST = DESCRIPTOR.message_types_by_name['RunAutomationRequest']
_RUNAUTOMATIONRESPONSE = DESCRIPTOR.message_types_by_name['RunAutomationResponse']
CreateAutomationRequest = _reflection.GeneratedProtocolMessageType('CreateAutomationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAUTOMATIONREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.CreateAutomationRequest)
  })
_sym_db.RegisterMessage(CreateAutomationRequest)

CreateAutomationResponse = _reflection.GeneratedProtocolMessageType('CreateAutomationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAUTOMATIONRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.CreateAutomationResponse)
  })
_sym_db.RegisterMessage(CreateAutomationResponse)

UpdateAutomationRequest = _reflection.GeneratedProtocolMessageType('UpdateAutomationRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAUTOMATIONREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.UpdateAutomationRequest)
  })
_sym_db.RegisterMessage(UpdateAutomationRequest)

UpdateAutomationResponse = _reflection.GeneratedProtocolMessageType('UpdateAutomationResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAUTOMATIONRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.UpdateAutomationResponse)
  })
_sym_db.RegisterMessage(UpdateAutomationResponse)

DeleteAutomationRequest = _reflection.GeneratedProtocolMessageType('DeleteAutomationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAUTOMATIONREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.DeleteAutomationRequest)
  })
_sym_db.RegisterMessage(DeleteAutomationRequest)

DeleteAutomationResponse = _reflection.GeneratedProtocolMessageType('DeleteAutomationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAUTOMATIONRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.DeleteAutomationResponse)
  })
_sym_db.RegisterMessage(DeleteAutomationResponse)

ListAutomationsRequest = _reflection.GeneratedProtocolMessageType('ListAutomationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAUTOMATIONSREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.ListAutomationsRequest)
  })
_sym_db.RegisterMessage(ListAutomationsRequest)

ListAutomationsResponse = _reflection.GeneratedProtocolMessageType('ListAutomationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAUTOMATIONSRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.ListAutomationsResponse)
  })
_sym_db.RegisterMessage(ListAutomationsResponse)

GetAutomationRequest = _reflection.GeneratedProtocolMessageType('GetAutomationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTOMATIONREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.GetAutomationRequest)
  })
_sym_db.RegisterMessage(GetAutomationRequest)

GetAutomationResponse = _reflection.GeneratedProtocolMessageType('GetAutomationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTOMATIONRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.GetAutomationResponse)
  })
_sym_db.RegisterMessage(GetAutomationResponse)

GetAutomationByNameRequest = _reflection.GeneratedProtocolMessageType('GetAutomationByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTOMATIONBYNAMEREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.GetAutomationByNameRequest)
  })
_sym_db.RegisterMessage(GetAutomationByNameRequest)

GetAutomationByNameResponse = _reflection.GeneratedProtocolMessageType('GetAutomationByNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTOMATIONBYNAMERESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.GetAutomationByNameResponse)
  })
_sym_db.RegisterMessage(GetAutomationByNameResponse)

ListAutomationExecutionsRequest = _reflection.GeneratedProtocolMessageType('ListAutomationExecutionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAUTOMATIONEXECUTIONSREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.ListAutomationExecutionsRequest)
  })
_sym_db.RegisterMessage(ListAutomationExecutionsRequest)

ListAutomationExecutionsResponse = _reflection.GeneratedProtocolMessageType('ListAutomationExecutionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAUTOMATIONEXECUTIONSRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.ListAutomationExecutionsResponse)
  })
_sym_db.RegisterMessage(ListAutomationExecutionsResponse)

ListLastAutomationExecutionsRequest = _reflection.GeneratedProtocolMessageType('ListLastAutomationExecutionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLASTAUTOMATIONEXECUTIONSREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.ListLastAutomationExecutionsRequest)
  })
_sym_db.RegisterMessage(ListLastAutomationExecutionsRequest)

ListLastAutomationExecutionsResponse = _reflection.GeneratedProtocolMessageType('ListLastAutomationExecutionsResponse', (_message.Message,), {

  'LastAutomationExecutionByAutomationIdEntry' : _reflection.GeneratedProtocolMessageType('LastAutomationExecutionByAutomationIdEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY,
    '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
    # @@protoc_insertion_point(class_scope:qwak.automation.v1.ListLastAutomationExecutionsResponse.LastAutomationExecutionByAutomationIdEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLASTAUTOMATIONEXECUTIONSRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.ListLastAutomationExecutionsResponse)
  })
_sym_db.RegisterMessage(ListLastAutomationExecutionsResponse)
_sym_db.RegisterMessage(ListLastAutomationExecutionsResponse.LastAutomationExecutionByAutomationIdEntry)

RegisterAutomationExecutionRequest = _reflection.GeneratedProtocolMessageType('RegisterAutomationExecutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERAUTOMATIONEXECUTIONREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.RegisterAutomationExecutionRequest)
  })
_sym_db.RegisterMessage(RegisterAutomationExecutionRequest)

RegisterAutomationExecutionResponse = _reflection.GeneratedProtocolMessageType('RegisterAutomationExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERAUTOMATIONEXECUTIONRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.RegisterAutomationExecutionResponse)
  })
_sym_db.RegisterMessage(RegisterAutomationExecutionResponse)

UpdateAutomationExecutionRequest = _reflection.GeneratedProtocolMessageType('UpdateAutomationExecutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAUTOMATIONEXECUTIONREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.UpdateAutomationExecutionRequest)
  })
_sym_db.RegisterMessage(UpdateAutomationExecutionRequest)

UpdateAutomationExecutionResponse = _reflection.GeneratedProtocolMessageType('UpdateAutomationExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAUTOMATIONEXECUTIONRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.UpdateAutomationExecutionResponse)
  })
_sym_db.RegisterMessage(UpdateAutomationExecutionResponse)

ToggleAutomationActivityRequest = _reflection.GeneratedProtocolMessageType('ToggleAutomationActivityRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEAUTOMATIONACTIVITYREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.ToggleAutomationActivityRequest)
  })
_sym_db.RegisterMessage(ToggleAutomationActivityRequest)

ToggleAutomationActivityResponse = _reflection.GeneratedProtocolMessageType('ToggleAutomationActivityResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEAUTOMATIONACTIVITYRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.ToggleAutomationActivityResponse)
  })
_sym_db.RegisterMessage(ToggleAutomationActivityResponse)

RunAutomationRequest = _reflection.GeneratedProtocolMessageType('RunAutomationRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNAUTOMATIONREQUEST,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.RunAutomationRequest)
  })
_sym_db.RegisterMessage(RunAutomationRequest)

RunAutomationResponse = _reflection.GeneratedProtocolMessageType('RunAutomationResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNAUTOMATIONRESPONSE,
  '__module__' : 'qwak.automation.v1.automation_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.RunAutomationResponse)
  })
_sym_db.RegisterMessage(RunAutomationResponse)

_AUTOMATIONMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['AutomationManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY._options = None
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY._serialized_options = b'8\001'
  _CREATEAUTOMATIONREQUEST._serialized_start=162
  _CREATEAUTOMATIONREQUEST._serialized_end=248
  _CREATEAUTOMATIONRESPONSE._serialized_start=250
  _CREATEAUTOMATIONRESPONSE._serialized_end=299
  _UPDATEAUTOMATIONREQUEST._serialized_start=301
  _UPDATEAUTOMATIONREQUEST._serialized_end=410
  _UPDATEAUTOMATIONRESPONSE._serialized_start=412
  _UPDATEAUTOMATIONRESPONSE._serialized_end=438
  _DELETEAUTOMATIONREQUEST._serialized_start=440
  _DELETEAUTOMATIONREQUEST._serialized_end=488
  _DELETEAUTOMATIONRESPONSE._serialized_start=490
  _DELETEAUTOMATIONRESPONSE._serialized_end=516
  _LISTAUTOMATIONSREQUEST._serialized_start=518
  _LISTAUTOMATIONSREQUEST._serialized_end=560
  _LISTAUTOMATIONSRESPONSE._serialized_start=562
  _LISTAUTOMATIONSRESPONSE._serialized_end=640
  _GETAUTOMATIONREQUEST._serialized_start=642
  _GETAUTOMATIONREQUEST._serialized_end=687
  _GETAUTOMATIONRESPONSE._serialized_start=689
  _GETAUTOMATIONRESPONSE._serialized_end=764
  _GETAUTOMATIONBYNAMEREQUEST._serialized_start=766
  _GETAUTOMATIONBYNAMEREQUEST._serialized_end=819
  _GETAUTOMATIONBYNAMERESPONSE._serialized_start=821
  _GETAUTOMATIONBYNAMERESPONSE._serialized_end=902
  _LISTAUTOMATIONEXECUTIONSREQUEST._serialized_start=904
  _LISTAUTOMATIONEXECUTIONSREQUEST._serialized_end=1011
  _LISTAUTOMATIONEXECUTIONSRESPONSE._serialized_start=1013
  _LISTAUTOMATIONEXECUTIONSRESPONSE._serialized_end=1126
  _LISTLASTAUTOMATIONEXECUTIONSREQUEST._serialized_start=1128
  _LISTLASTAUTOMATIONEXECUTIONSREQUEST._serialized_end=1183
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE._serialized_start=1186
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE._serialized_end=1504
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY._serialized_start=1380
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY._serialized_end=1504
  _REGISTERAUTOMATIONEXECUTIONREQUEST._serialized_start=1506
  _REGISTERAUTOMATIONEXECUTIONREQUEST._serialized_end=1587
  _REGISTERAUTOMATIONEXECUTIONRESPONSE._serialized_start=1589
  _REGISTERAUTOMATIONEXECUTIONRESPONSE._serialized_end=1626
  _UPDATEAUTOMATIONEXECUTIONREQUEST._serialized_start=1628
  _UPDATEAUTOMATIONEXECUTIONREQUEST._serialized_end=1753
  _UPDATEAUTOMATIONEXECUTIONRESPONSE._serialized_start=1755
  _UPDATEAUTOMATIONEXECUTIONRESPONSE._serialized_end=1790
  _TOGGLEAUTOMATIONACTIVITYREQUEST._serialized_start=1792
  _TOGGLEAUTOMATIONACTIVITYREQUEST._serialized_end=1868
  _TOGGLEAUTOMATIONACTIVITYRESPONSE._serialized_start=1870
  _TOGGLEAUTOMATIONACTIVITYRESPONSE._serialized_end=1904
  _RUNAUTOMATIONREQUEST._serialized_start=1906
  _RUNAUTOMATIONREQUEST._serialized_end=1951
  _RUNAUTOMATIONRESPONSE._serialized_start=1953
  _RUNAUTOMATIONRESPONSE._serialized_end=1976
  _AUTOMATIONMANAGEMENTSERVICE._serialized_start=1979
  _AUTOMATIONMANAGEMENTSERVICE._serialized_end=3477
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/alert.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bqwak/deployment/alert.proto\x12\x1aqwak.deployment.management\"\xe2\x01\n\tAlertRule\x12\x39\n\nalert_spec\x18\x01 \x01(\x0b\x32%.qwak.deployment.management.AlertSpec\x12S\n\x16notifications_channels\x18\x02 \x03(\x0b\x32\x33.qwak.deployment.management.NotificationChannelSpec\x12\x10\n\x08\x61lert_id\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\x12\x1f\n\x17selected_variation_name\x18\x05 \x01(\t\"\xaa\x02\n\tAlertSpec\x12\x45\n\x10reducer_function\x18\x01 \x01(\x0e\x32+.qwak.deployment.management.ReducerFunction\x12\x41\n\x0e\x65valuator_type\x18\x02 \x01(\x0e\x32).qwak.deployment.management.EvaluatorType\x12\x1f\n\x13\x65valuator_threshold\x18\x03 \x01(\x05\x42\x02\x18\x01\x12\x19\n\x11\x65valuation_period\x18\x04 \x01(\x05\x12\x39\n\nalert_type\x18\x05 \x01(\x0e\x32%.qwak.deployment.management.AlertType\x12\x1c\n\x14\x65valuation_threshold\x18\x06 \x01(\x02\"]\n\x17NotificationChannelSpec\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12!\n\x19notification_channel_name\x18\x02 \x01(\t\"\xb1\x01\n\x13NotificationChannel\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12!\n\x19notification_channel_name\x18\x02 \x01(\t\x12V\n\x15notification_settings\x18\x03 \x01(\x0b\x32\x37.qwak.deployment.management.NotificationChannelSettings\"\xb5\x01\n\x1bNotificationChannelSettings\x12\x43\n\x0eslack_settings\x18\x01 \x01(\x0b\x32).qwak.deployment.management.SlackSettingsH\x00\x12I\n\x11opsgenie_settings\x18\x02 \x01(\x0b\x32,.qwak.deployment.management.OpsgenieSettingsH\x00\x42\x06\n\x04type\"\x1c\n\rSlackSettings\x12\x0b\n\x03url\x18\x01 \x01(\t\"4\n\x10OpsgenieSettings\x12\x0f\n\x07\x61pi_url\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t*\x82\x01\n\tAlertType\x12\x18\n\x14\x41LERT_TYPE_NOT_VALID\x10\x00\x12\x0e\n\nERROR_RATE\x10\x01\x12\x0e\n\nTHROUGHPUT\x10\x02\x12\x0b\n\x07LATENCY\x10\x03\x12\x0e\n\nLATENCY_90\x10\x04\x12\x0e\n\nLATENCY_95\x10\x05\x12\x0e\n\nLATENCY_99\x10\x06*\xad\x01\n\x0fReducerFunction\x12\x1e\n\x1aREDUCER_FUNCTION_NOT_VALID\x10\x00\x12\x07\n\x03MIN\x10\x01\x12\x07\n\x03MAX\x10\x02\x12\x07\n\x03SUM\x10\x03\x12\t\n\x05\x43OUNT\x10\x04\x12\x08\n\x04LAST\x10\x05\x12\n\n\x06MEDIAN\x10\x06\x12\x08\n\x04\x44IFF\x10\x07\x12\x0c\n\x08\x44IFF_ABS\x10\x08\x12\x10\n\x0cPERCENT_DIFF\x10\t\x12\x14\n\x10PERCENT_DIFF_ABS\x10\n*I\n\rEvaluatorType\x12\x1c\n\x18\x45VALUATOR_TYPE_NOT_VALID\x10\x00\x12\x0c\n\x08IS_ABOVE\x10\x01\x12\x0c\n\x08IS_BELOW\x10\x02\x42)\n%com.qwak.ai.management.deployment.apiP\x01\x62\x06proto3')

_ALERTTYPE = DESCRIPTOR.enum_types_by_name['AlertType']
AlertType = enum_type_wrapper.EnumTypeWrapper(_ALERTTYPE)
_REDUCERFUNCTION = DESCRIPTOR.enum_types_by_name['ReducerFunction']
ReducerFunction = enum_type_wrapper.EnumTypeWrapper(_REDUCERFUNCTION)
_EVALUATORTYPE = DESCRIPTOR.enum_types_by_name['EvaluatorType']
EvaluatorType = enum_type_wrapper.EnumTypeWrapper(_EVALUATORTYPE)
ALERT_TYPE_NOT_VALID = 0
ERROR_RATE = 1
THROUGHPUT = 2
LATENCY = 3
LATENCY_90 = 4
LATENCY_95 = 5
LATENCY_99 = 6
REDUCER_FUNCTION_NOT_VALID = 0
MIN = 1
MAX = 2
SUM = 3
COUNT = 4
LAST = 5
MEDIAN = 6
DIFF = 7
DIFF_ABS = 8
PERCENT_DIFF = 9
PERCENT_DIFF_ABS = 10
EVALUATOR_TYPE_NOT_VALID = 0
IS_ABOVE = 1
IS_BELOW = 2


_ALERTRULE = DESCRIPTOR.message_types_by_name['AlertRule']
_ALERTSPEC = DESCRIPTOR.message_types_by_name['AlertSpec']
_NOTIFICATIONCHANNELSPEC = DESCRIPTOR.message_types_by_name['NotificationChannelSpec']
_NOTIFICATIONCHANNEL = DESCRIPTOR.message_types_by_name['NotificationChannel']
_NOTIFICATIONCHANNELSETTINGS = DESCRIPTOR.message_types_by_name['NotificationChannelSettings']
_SLACKSETTINGS = DESCRIPTOR.message_types_by_name['SlackSettings']
_OPSGENIESETTINGS = DESCRIPTOR.message_types_by_name['OpsgenieSettings']
AlertRule = _reflection.GeneratedProtocolMessageType('AlertRule', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRULE,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.AlertRule)
  })
_sym_db.RegisterMessage(AlertRule)

AlertSpec = _reflection.GeneratedProtocolMessageType('AlertSpec', (_message.Message,), {
  'DESCRIPTOR' : _ALERTSPEC,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.AlertSpec)
  })
_sym_db.RegisterMessage(AlertSpec)

NotificationChannelSpec = _reflection.GeneratedProtocolMessageType('NotificationChannelSpec', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONCHANNELSPEC,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.NotificationChannelSpec)
  })
_sym_db.RegisterMessage(NotificationChannelSpec)

NotificationChannel = _reflection.GeneratedProtocolMessageType('NotificationChannel', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONCHANNEL,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.NotificationChannel)
  })
_sym_db.RegisterMessage(NotificationChannel)

NotificationChannelSettings = _reflection.GeneratedProtocolMessageType('NotificationChannelSettings', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONCHANNELSETTINGS,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.NotificationChannelSettings)
  })
_sym_db.RegisterMessage(NotificationChannelSettings)

SlackSettings = _reflection.GeneratedProtocolMessageType('SlackSettings', (_message.Message,), {
  'DESCRIPTOR' : _SLACKSETTINGS,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.SlackSettings)
  })
_sym_db.RegisterMessage(SlackSettings)

OpsgenieSettings = _reflection.GeneratedProtocolMessageType('OpsgenieSettings', (_message.Message,), {
  'DESCRIPTOR' : _OPSGENIESETTINGS,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.OpsgenieSettings)
  })
_sym_db.RegisterMessage(OpsgenieSettings)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001'
  _ALERTSPEC.fields_by_name['evaluator_threshold']._options = None
  _ALERTSPEC.fields_by_name['evaluator_threshold']._serialized_options = b'\030\001'
  _ALERTTYPE._serialized_start=1133
  _ALERTTYPE._serialized_end=1263
  _REDUCERFUNCTION._serialized_start=1266
  _REDUCERFUNCTION._serialized_end=1439
  _EVALUATORTYPE._serialized_start=1441
  _EVALUATORTYPE._serialized_end=1514
  _ALERTRULE._serialized_start=60
  _ALERTRULE._serialized_end=286
  _ALERTSPEC._serialized_start=289
  _ALERTSPEC._serialized_end=587
  _NOTIFICATIONCHANNELSPEC._serialized_start=589
  _NOTIFICATIONCHANNELSPEC._serialized_end=682
  _NOTIFICATIONCHANNEL._serialized_start=685
  _NOTIFICATIONCHANNEL._serialized_end=862
  _NOTIFICATIONCHANNELSETTINGS._serialized_start=865
  _NOTIFICATIONCHANNELSETTINGS._serialized_end=1046
  _SLACKSETTINGS._serialized_start=1048
  _SLACKSETTINGS._serialized_end=1076
  _OPSGENIESETTINGS._serialized_start=1078
  _OPSGENIESETTINGS._serialized_end=1130
# @@protoc_insertion_point(module_scope)



from typing import List, Optional

import grpc
from _qwak_proto.qwak.vectors.v1.filters_pb2 import Filter as ProtoFilter
from _qwak_proto.qwak.vectors.v1.vector_pb2 import (
    DoubleVector,
    SearchResult,
    StoredVector,
    VectorIdentifier,
)
from _qwak_proto.qwak.vectors.v1.vector_service_pb2 import (
    DeleteVectorsRequest,
    FetchVectorRequest,
    SearchSimilarVectorsRequest,
    UpsertVectorsRequest,
)
from _qwak_proto.qwak.vectors.v1.vector_service_pb2_grpc import VectorServiceStub
from qwak.clients._inner.edge_communications import get_endpoint_url
from qwak.exceptions import QwakException, QwakNotFoundException
from qwak.inner.tool.grpc.grpc_tools import create_grpc_channel
from typeguard import typechecked


class VectorServingClient:
    def __init__(
        self,
        edge_services_url: Optional[str] = None,
        environment_id: Optional[str] = None,
    ):
        edge_services_url = get_endpoint_url(edge_services_url, environment_id)
        self._edge_services_url = edge_services_url

        grpc_channel = create_grpc_channel(
            url=edge_services_url,
            enable_ssl=False if edge_services_url.startswith("localhost") else True,
            status_for_retry=(
                grpc.StatusCode.UNAVAILABLE,
                grpc.StatusCode.DEADLINE_EXCEEDED,
                grpc.StatusCode.INTERNAL,
            ),
            backoff_options={"init_backoff_ms": 250},
        )

        self._vector_serving_service = VectorServiceStub(grpc_channel)

    @typechecked
    def search(
        self,
        collection_name: str,
        vector: List[float],
        properties: List[str],
        top_results: int = 1,
        include_id: bool = True,
        include_vector: bool = False,
        include_distance: bool = False,
        filters: Optional[ProtoFilter] = None,
        tenant_id: Optional[str] = None,
    ) -> List[SearchResult]:
        """
        Search for similar vectors
        """
        request: SearchSimilarVectorsRequest
        if tenant_id is not None:
            request = SearchSimilarVectorsRequest(
                collection_name=collection_name,
                reference_vector=DoubleVector(element=vector),
                properties=properties,
                max_results=top_results,
                filter=filters,
                include_id=include_id,
                include_vector=include_vector,
                include_distance=include_distance,
                tenant_id=tenant_id,
            )
        else:
            request = SearchSimilarVectorsRequest(
                collection_name=collection_name,
                reference_vector=DoubleVector(element=vector),
                properties=properties,
                max_results=top_results,
                filter=filters,
                include_id=include_id,
                include_vector=include_vector,
                include_distance=include_distance,
            )

        try:
            return list(
                self._vector_serving_service.SearchSimilarVectors(
                    request
                ).search_results
            )

        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to query collection '{collection_name}' for vector '{str(vector)}': {repr(e)}"
            )

    @typechecked
    def upsert_vectors(self, collection_name: str, vectors: List[StoredVector]) -> None:
        """
        Upsert vectors to a collection
        """
        try:
            self._vector_serving_service.UpsertVectors(
                UpsertVectorsRequest(
                    collection_name=collection_name,
                    vector=vectors,
                )
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to upsert, got: {repr(e)}")

    @typechecked
    def delete_vectors(
        self, collection_name: str, vector_identifiers: List[VectorIdentifier]
    ) -> int:
        """
        Delete vectors from a collection
        """
        try:
            return self._vector_serving_service.DeleteVectors(
                DeleteVectorsRequest(
                    collection_name=collection_name,
                    vector_identifiers=vector_identifiers,
                )
            ).num_vectors_deleted

        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to delete vectors by id '{str(vector_identifiers)}': {repr(e)}"
            )

    @typechecked
    def fetch_vector(
        self, collection_name: str, vector_identifier: VectorIdentifier
    ) -> StoredVector:
        """
        Fetch a vector from a collection
        """
        try:
            return self._vector_serving_service.FetchVector(
                FetchVectorRequest(
                    collection_name=collection_name, vector_identifier=vector_identifier
                )
            ).vector

        except grpc.RpcError as e:
            if e.args[0].code.name == "NOT_FOUND":
                raise QwakNotFoundException(
                    f"Could not find vector {repr(vector_identifier)} in collection {collection_name}"
                )
            raise QwakException(
                f"Failed to get vector by ID '{vector_identifier}': {repr(e)}"
            )



import grpc
from _qwak_proto.qwak.deployment.alert_pb2 import (
    NotificationChannel,
    NotificationChannelSettings,
)
from _qwak_proto.qwak.deployment.alert_service_pb2 import (
    ApplyNotificationChannelRequest,
    DeleteNotificationChannelRequest,
    GetNotificationChannelDetailsListRequest,
)
from _qwak_proto.qwak.deployment.alert_service_pb2_grpc import (
    AlertManagementServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class AlertsManagementClient:
    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._alerts_management_service = AlertManagementServiceStub(grpc_channel)

    def configure_channel(
        self, channel_name: str, notification_settings: NotificationChannelSettings
    ):
        try:
            self._alerts_management_service.ApplyNotificationChannel(
                ApplyNotificationChannelRequest(
                    notification_channel=NotificationChannel(
                        notification_channel_name=channel_name,
                        notification_settings=notification_settings,
                    ),
                )
            )

        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to save notification channel, error is {e.details()}"
            )

    def list_channels(self):
        try:
            return self._alerts_management_service.GetNotificationChannelDetailsList(
                GetNotificationChannelDetailsListRequest()
            )

        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to fetch notification channels, error is {e.details()}"
            )

    def delete_channel(self, notification_channel_id):
        try:
            self._alerts_management_service.DeleteNotificationChannel(
                DeleteNotificationChannelRequest(
                    notification_channel_id=notification_channel_id
                )
            )

        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to delete notification channel, error is {e.details()}"
            )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class JfrogTenantDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TENANT_ID_FIELD_NUMBER: builtins.int
    DEFAULT_JFROG_PROJECT_DETAILS_FIELD_NUMBER: builtins.int
    JFROG_TENANT_CONFIGURATION_FIELD_NUMBER: builtins.int
    tenant_id: builtins.str
    """The JFrog tenant's ID"""
    @property
    def default_jfrog_project_details(self) -> global___JfrogProjectDetails:
        """JFrog project details"""
    @property
    def jfrog_tenant_configuration(self) -> global___JFrogTenantConfiguration:
        """The JFrog tenant's configuration"""
    def __init__(
        self,
        *,
        tenant_id: builtins.str = ...,
        default_jfrog_project_details: global___JfrogProjectDetails | None = ...,
        jfrog_tenant_configuration: global___JFrogTenantConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_jfrog_project_details", b"default_jfrog_project_details", "jfrog_tenant_configuration", b"jfrog_tenant_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_jfrog_project_details", b"default_jfrog_project_details", "jfrog_tenant_configuration", b"jfrog_tenant_configuration", "tenant_id", b"tenant_id"]) -> None: ...

global___JfrogTenantDetails = JfrogTenantDetails

class JFrogTenantConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_JFROG_PROJECT_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def default_jfrog_project_details(self) -> global___JfrogProjectDetails:
        """JFrog project details"""
    def __init__(
        self,
        *,
        default_jfrog_project_details: global___JfrogProjectDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_jfrog_project_details", b"default_jfrog_project_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_jfrog_project_details", b"default_jfrog_project_details"]) -> None: ...

global___JFrogTenantConfiguration = JFrogTenantConfiguration

class JfrogProjectDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_KEY_FIELD_NUMBER: builtins.int
    project_key: builtins.str
    """The JFrog project's key"""
    def __init__(
        self,
        *,
        project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_key", b"project_key"]) -> None: ...

global___JfrogProjectDetails = JfrogProjectDetails

class JfrogTenantSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TENANT_ID_FIELD_NUMBER: builtins.int
    DEFAULT_PROJECT_SPEC_FIELD_NUMBER: builtins.int
    tenant_id: builtins.str
    """The JFrog tenant's ID"""
    @property
    def default_project_spec(self) -> global___JfrogProjectSpec:
        """The JFrog tenant's default project details"""
    def __init__(
        self,
        *,
        tenant_id: builtins.str = ...,
        default_project_spec: global___JfrogProjectSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_project_spec", b"default_project_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_project_spec", b"default_project_spec", "tenant_id", b"tenant_id"]) -> None: ...

global___JfrogTenantSpec = JfrogTenantSpec

class JfrogProjectSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_KEY_FIELD_NUMBER: builtins.int
    project_key: builtins.str
    """The JFrog project's key"""
    def __init__(
        self,
        *,
        project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_key", b"project_key"]) -> None: ...

global___JfrogProjectSpec = JfrogProjectSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MonitoringConfigurations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONITORING_FIELD_NUMBER: builtins.int
    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]: ...
    def __init__(
        self,
        *,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitoring", b"monitoring"]) -> None: ...

global___MonitoringConfigurations = MonitoringConfigurations

class Monitoring(google.protobuf.message.Message):
    """Represents the Monitoring configuration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILURE_ALERT_FIELD_NUMBER: builtins.int
    @property
    def failure_alert(self) -> global___FailureAlert: ...
    def __init__(
        self,
        *,
        failure_alert: global___FailureAlert | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failure_alert", b"failure_alert", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_alert", b"failure_alert", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["failure_alert"] | None: ...

global___Monitoring = Monitoring

class FailureAlert(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMES_FIELD_NUMBER: builtins.int
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of channel names to be reported on failure"""
    def __init__(
        self,
        *,
        names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["names", b"names"]) -> None: ...

global___FailureAlert = FailureAlert



from qwak.exceptions import QwakException


def protobuf_factory(
    protobuf_class, exclude_fields=None, include_only=None, mapping=None
):
    def get_final_field_names(cls):
        fields = dict(cls.__dataclass_fields__)
        all_field_names = set(fields.keys())
        excluded_fields = set(exclude_fields) if exclude_fields else set()
        included_fields = set(include_only) if include_only else all_field_names
        unrecognized_fields = included_fields.difference(all_field_names)
        if unrecognized_fields:
            raise QwakException(
                f"Unknown fields were included: {list(unrecognized_fields)}"
            )
        return included_fields.difference(excluded_fields)

    def protofy_decorator(cls):
        if not hasattr(cls, "__dataclass_fields__"):
            raise QwakException("Protofy must receive a dataclass")

        fields_mapping = mapping if mapping else {}
        final_field_names = get_final_field_names(cls)

        def to_proto(self) -> protobuf_class:
            final_fields = {}
            for field_name in final_field_names:
                field_val = self.__getattribute__(field_name)
                field_name = (
                    fields_mapping[field_name]
                    if field_name in fields_mapping
                    else field_name
                )
                final_fields[field_name] = (
                    field_val.to_proto()
                    if hasattr(field_val, "to_proto")
                    else field_val
                )
            return protobuf_class(**final_fields)

        setattr(cls, "to_proto", to_proto)
        return cls

    return protofy_decorator



from typing import Any

from .base_output_adapter import BaseOutputAdapter


class JsonOutputAdapter(BaseOutputAdapter):
    @staticmethod
    def pack_user_func_return_value(return_result: Any) -> str:
        pass



import grpc
from _qwak_proto.qwak.projects.projects_pb2 import (
    CreateProjectRequest,
    DeleteProjectRequest,
    GetProjectRequest,
    ListProjectsRequest,
)
from _qwak_proto.qwak.projects.projects_pb2_grpc import ProjectsManagementServiceStub
from dependency_injector.wiring import Provide, inject
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class ProjectsManagementClient:
    """
    Used for interacting with Project Management endpoints
    """

    @inject
    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._projects_management_service = ProjectsManagementServiceStub(grpc_channel)

    def list_projects(self):
        try:
            return self._projects_management_service.ListProjects(ListProjectsRequest())

        except grpc.RpcError as e:
            raise QwakException(f"Failed to list projects, error is {e.details()}")

    def create_project(self, project_name, project_description):
        try:
            return self._projects_management_service.CreateProject(
                CreateProjectRequest(
                    project_name=project_name, project_description=project_description
                )
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to create project, error is {e.details()}")

    def delete_project(self, project_id):
        try:
            return self._projects_management_service.DeleteProject(
                DeleteProjectRequest(project_id=project_id)
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to delete project, error is {e.details()}")

    def get_project(self, project_id: str = "", project_name: str = ""):
        try:
            return self._projects_management_service.GetProject(
                GetProjectRequest(project_id=project_id, project_name=project_name)
            )

        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to fetch models associated with project id {project_id}, error is {e.details()}"
            )



import inspect
from abc import ABC, abstractmethod
from dataclasses import dataclass, field
from typing import Optional

from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    Aggregation as AggregationProto,
)
from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    AggregationPopulation as AggregationPopulationProto,
)
from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    DataSourceReadPolicy as ProtoDataSourceReadPolicy,
)
from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    FullRead as ProtoFullRead,
)
from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    NewOnly as ProtoNewOnly,
)
from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    PopulationTimeframe as PopulationTimeframeProto,
)
from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    PopulationTimeframeNewOnly as PopulationTimeframeNewOnlyProto,
)
from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    TimeFrame as ProtoTimeFrame,
)
from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    Vanilla as VanillaProto,
)
from qwak.exceptions import QwakException


class ReadPolicyABC(ABC):
    @abstractmethod
    def to_proto(self):
        pass

    @classmethod
    def from_proto(cls, proto: "ProtoDataSourceReadPolicy"):
        read_policy_mapping = {
            "time_frame": TimeFrame,
            "new_only": NewOnly,
            "full_read": FullRead,
        }

        read_policy_type: str = proto.WhichOneof("type")
        if read_policy_type in read_policy_mapping:
            read_policy_class = read_policy_mapping.get(read_policy_type)
            return read_policy_class.from_proto(proto)

        raise QwakException(f"Got unsupported read policy type: {read_policy_type}")


class NewOnly(ReadPolicyABC):
    def to_proto(self):
        return ProtoDataSourceReadPolicy(new_only=ProtoNewOnly())

    @classmethod
    def from_proto(cls, proto):
        return cls()


class TimeFrameFlavor(ABC):
    @abstractmethod
    def to_proto(self):
        pass


class Vanilla(TimeFrameFlavor):
    def to_proto(self):
        return VanillaProto()

    @classmethod
    def from_proto(cls, proto):
        return cls()


class Aggregation(TimeFrameFlavor):
    @abstractmethod
    def to_proto(self):
        pass

    @classmethod
    def from_proto(cls, proto):
        return cls()


class AggregationPopulation(Aggregation):
    def to_proto(self):
        return AggregationProto(aggregation_population=AggregationPopulationProto())

    @classmethod
    def from_proto(cls, proto):
        return cls()


@dataclass
class TimeFrame(ReadPolicyABC):
    days: int = 0
    hours: int = 0
    minutes: int = 0
    flavor: Optional[TimeFrameFlavor] = field(default_factory=lambda: Vanilla())

    def to_proto(self):
        if isinstance(self.flavor, Aggregation):
            return ProtoDataSourceReadPolicy(
                time_frame=ProtoTimeFrame(
                    minutes=self._get_time_frame_total_minutes(),
                    aggregation=self.flavor.to_proto(),
                )
            )
        return ProtoDataSourceReadPolicy(
            time_frame=ProtoTimeFrame(
                minutes=self._get_time_frame_total_minutes(),
                vanilla=self.flavor.to_proto(),
            )
        )

    @classmethod
    def from_proto(cls, proto):
        flavor_mapping = {
            "vanilla": Vanilla,
            "aggregation": AggregationPopulation,
        }

        minutes_raw = proto.time_frame.minutes

        days = minutes_raw // 1440  # (24 * 60)
        leftover_minutes = minutes_raw % 1440
        hours = leftover_minutes // 60
        mins = minutes_raw - (days * 1440) - (hours * 60)

        flavor_type = proto.time_frame.WhichOneof("flavor")
        return cls(
            days=days,
            hours=hours,
            minutes=mins,
            flavor=flavor_mapping.get(flavor_type).from_proto(proto),
        )

    def __post_init__(self):
        self._validate_positive_integer(self.days, "days")
        self._validate_positive_integer(self.hours, "hours")
        self._validate_positive_integer(self.minutes, "minutes")
        if self._get_time_frame_total_minutes() <= 0:
            raise QwakException(
                "Time frame must have a positive amount of time, "
                "it is mandatory to set one of the fields"
            )
        if inspect.isclass(self.flavor):
            self.flavor = self.flavor()

    def _get_time_frame_total_minutes(self):
        return self.days * 24 * 60 + self.hours * 60 + self.minutes

    @staticmethod
    def _validate_positive_integer(int_value, field_name):
        if not isinstance(int_value, int) or int_value < 0:
            raise QwakException(f"{field_name} must be a positive integer")


class FullReadFlavor(ABC):
    @abstractmethod
    def to_proto(self):
        pass

    @classmethod
    def from_proto(cls, proto):
        return cls()


class FullReadVanilla(FullReadFlavor):
    def to_proto(self):
        return VanillaProto()

    @classmethod
    def from_proto(cls, proto):
        return cls()


class PopulationTimeframe(FullReadFlavor):
    @abstractmethod
    def to_proto(self):
        pass

    @classmethod
    def from_proto(cls, proto):
        return cls()


class PopulationTimeframeNewOnly(PopulationTimeframe):
    def to_proto(self):
        return PopulationTimeframeProto(new_only=PopulationTimeframeNewOnlyProto())

    @classmethod
    def from_proto(cls, proto):
        return cls()


@dataclass
class FullRead(ReadPolicyABC):
    flavor: Optional[FullReadFlavor] = field(default_factory=lambda: FullReadVanilla())

    def __post_init__(self):
        if inspect.isclass(self.flavor):
            self.flavor = self.flavor()

    @classmethod
    def from_proto(cls, proto):
        flavor_mapping = {
            "default": FullReadVanilla,
            "population_timeframe": PopulationTimeframeNewOnly,
        }

        flavor_type = proto.full_read.WhichOneof("flavor")
        return cls(
            flavor=flavor_mapping.get(flavor_type).from_proto(proto),
        )

    def to_proto(self):
        if isinstance(self.flavor, PopulationTimeframe):
            return ProtoDataSourceReadPolicy(
                full_read=ProtoFullRead(population_timeframe=self.flavor.to_proto())
            )

        return ProtoDataSourceReadPolicy(
            full_read=ProtoFullRead(default=self.flavor.to_proto())
        )


class Population:
    NewOnly = PopulationTimeframeNewOnly


class Aggregations:
    Population = AggregationPopulation


class ReadPolicy:
    NewOnly = NewOnly
    TimeFrame = TimeFrame
    FullRead = FullRead



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/authenticated_user/v1/details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/administration/authenticated_user/v1/details.proto\x12)qwak.administration.authenticated_user.v1\"/\n\x0bUserDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\"|\n\x12\x45nvironmentDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12Z\n\rconfiguration\x18\x02 \x01(\x0b\x32\x43.qwak.administration.authenticated_user.v1.EnvironmentConfiguration\"\xa5\x02\n\x18\x45nvironmentConfiguration\x12\x19\n\x11\x65\x64ge_services_url\x18\x01 \x01(\t\x12\x1d\n\x15management_access_url\x18\x06 \x01(\t\x12\x15\n\rmodel_api_url\x18\x02 \x01(\t\x12\x1e\n\x16\x61nalytics_data_api_url\x18\x03 \x01(\t\x12\x1d\n\x15object_storage_bucket\x18\x04 \x01(\t\x12\x19\n\x11\x62i_system_api_key\x18\x05 \x01(\t\x12^\n\x13\x63loud_configuration\x18\x07 \x01(\x0b\x32\x41.qwak.administration.authenticated_user.v1.QwakCloudConfiguration\"\x8e\x01\n\x16QwakCloudConfiguration\x12\x63\n\x17\x61ws_cloud_configuration\x18\x01 \x01(\x0b\x32@.qwak.administration.authenticated_user.v1.AwsCloudConfigurationH\x00\x42\x0f\n\rconfiguration\"a\n\x15\x41wsCloudConfiguration\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x11\n\tworkgroup\x18\x04 \x01(\tBN\n4com.qwak.ai.administration.api.authenticated_user.v1P\x01Z\x14.;authenticated_userb\x06proto3')



_USERDETAILS = DESCRIPTOR.message_types_by_name['UserDetails']
_ENVIRONMENTDETAILS = DESCRIPTOR.message_types_by_name['EnvironmentDetails']
_ENVIRONMENTCONFIGURATION = DESCRIPTOR.message_types_by_name['EnvironmentConfiguration']
_QWAKCLOUDCONFIGURATION = DESCRIPTOR.message_types_by_name['QwakCloudConfiguration']
_AWSCLOUDCONFIGURATION = DESCRIPTOR.message_types_by_name['AwsCloudConfiguration']
UserDetails = _reflection.GeneratedProtocolMessageType('UserDetails', (_message.Message,), {
  'DESCRIPTOR' : _USERDETAILS,
  '__module__' : 'qwak.administration.authenticated_user.v1.details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.UserDetails)
  })
_sym_db.RegisterMessage(UserDetails)

EnvironmentDetails = _reflection.GeneratedProtocolMessageType('EnvironmentDetails', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTDETAILS,
  '__module__' : 'qwak.administration.authenticated_user.v1.details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.EnvironmentDetails)
  })
_sym_db.RegisterMessage(EnvironmentDetails)

EnvironmentConfiguration = _reflection.GeneratedProtocolMessageType('EnvironmentConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTCONFIGURATION,
  '__module__' : 'qwak.administration.authenticated_user.v1.details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.EnvironmentConfiguration)
  })
_sym_db.RegisterMessage(EnvironmentConfiguration)

QwakCloudConfiguration = _reflection.GeneratedProtocolMessageType('QwakCloudConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _QWAKCLOUDCONFIGURATION,
  '__module__' : 'qwak.administration.authenticated_user.v1.details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.QwakCloudConfiguration)
  })
_sym_db.RegisterMessage(QwakCloudConfiguration)

AwsCloudConfiguration = _reflection.GeneratedProtocolMessageType('AwsCloudConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _AWSCLOUDCONFIGURATION,
  '__module__' : 'qwak.administration.authenticated_user.v1.details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.AwsCloudConfiguration)
  })
_sym_db.RegisterMessage(AwsCloudConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4com.qwak.ai.administration.api.authenticated_user.v1P\001Z\024.;authenticated_user'
  _USERDETAILS._serialized_start=102
  _USERDETAILS._serialized_end=149
  _ENVIRONMENTDETAILS._serialized_start=151
  _ENVIRONMENTDETAILS._serialized_end=275
  _ENVIRONMENTCONFIGURATION._serialized_start=278
  _ENVIRONMENTCONFIGURATION._serialized_end=571
  _QWAKCLOUDCONFIGURATION._serialized_start=574
  _QWAKCLOUDCONFIGURATION._serialized_end=716
  _AWSCLOUDCONFIGURATION._serialized_start=718
  _AWSCLOUDCONFIGURATION._serialized_end=815
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/user/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.self_service.user.v1 import user_pb2 as qwak_dot_self__service_dot_user_dot_v1_dot_user__pb2
from _qwak_proto.qwak.self_service.user.v1 import api_key_pb2 as qwak_dot_self__service_dot_user_dot_v1_dot_api__key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/self_service/user/v1/user_service.proto\x12\x19qwak.self_service.user.v1\x1a$qwak/self_service/user/v1/user.proto\x1a\'qwak/self_service/user/v1/api_key.proto\"O\n\x15GenerateApiKeyRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\")\n\x16GenerateApiKeyResponse\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\">\n\x13RevokeApiKeyRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\x8e\x01\n\x14RevokeApiKeyResponse\x12\x46\n\x06status\x18\x01 \x01(\x0e\x32\x36.qwak.self_service.user.v1.RevokeApiKeyResponse.Status\".\n\x06Status\x12\x17\n\x13INVALID_USER_STATUS\x10\x00\x12\x0b\n\x07REVOKED\x10\x01\"\x1a\n\x18ListApiKeyDetailsRequest\"\x86\x02\n\x19ListApiKeyDetailsResponse\x12|\n\x1e\x65nvironment_to_api_key_details\x18\x01 \x03(\x0b\x32T.qwak.self_service.user.v1.ListApiKeyDetailsResponse.EnvironmentToApiKeyDetailsEntry\x1ak\n\x1f\x45nvironmentToApiKeyDetailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qwak.self_service.user.v1.ApiKeyDetails:\x02\x38\x01\"\x17\n\x15GetUserProfileRequest\"V\n\x16GetUserProfileResponse\x12<\n\x0cuser_profile\x18\x01 \x01(\x0b\x32&.qwak.self_service.user.v1.UserProfile\"X\n\x18UpdateUserProfileRequest\x12<\n\x0cuser_profile\x18\x01 \x01(\x0b\x32&.qwak.self_service.user.v1.UserProfile\"a\n\x19UpdateUserProfileResponse\x12\x44\n\x14updated_user_profile\x18\x01 \x01(\x0b\x32&.qwak.self_service.user.v1.UserProfile2\xec\x04\n\x0bUserService\x12u\n\x0eGenerateApiKey\x12\x30.qwak.self_service.user.v1.GenerateApiKeyRequest\x1a\x31.qwak.self_service.user.v1.GenerateApiKeyResponse\x12o\n\x0cRevokeApiKey\x12..qwak.self_service.user.v1.RevokeApiKeyRequest\x1a/.qwak.self_service.user.v1.RevokeApiKeyResponse\x12~\n\x11ListApiKeyDetails\x12\x33.qwak.self_service.user.v1.ListApiKeyDetailsRequest\x1a\x34.qwak.self_service.user.v1.ListApiKeyDetailsResponse\x12u\n\x0eGetUserProfile\x12\x30.qwak.self_service.user.v1.GetUserProfileRequest\x1a\x31.qwak.self_service.user.v1.GetUserProfileResponse\x12~\n\x11UpdateUserProfile\x12\x33.qwak.self_service.user.v1.UpdateUserProfileRequest\x1a\x34.qwak.self_service.user.v1.UpdateUserProfileResponseB\xaf\x01\n\x1f\x63om.qwak.ai.self_service.v1.apiP\x01Z\x89\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/user/v1;self_service_user_v1b\x06proto3')



_GENERATEAPIKEYREQUEST = DESCRIPTOR.message_types_by_name['GenerateApiKeyRequest']
_GENERATEAPIKEYRESPONSE = DESCRIPTOR.message_types_by_name['GenerateApiKeyResponse']
_REVOKEAPIKEYREQUEST = DESCRIPTOR.message_types_by_name['RevokeApiKeyRequest']
_REVOKEAPIKEYRESPONSE = DESCRIPTOR.message_types_by_name['RevokeApiKeyResponse']
_LISTAPIKEYDETAILSREQUEST = DESCRIPTOR.message_types_by_name['ListApiKeyDetailsRequest']
_LISTAPIKEYDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['ListApiKeyDetailsResponse']
_LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY = _LISTAPIKEYDETAILSRESPONSE.nested_types_by_name['EnvironmentToApiKeyDetailsEntry']
_GETUSERPROFILEREQUEST = DESCRIPTOR.message_types_by_name['GetUserProfileRequest']
_GETUSERPROFILERESPONSE = DESCRIPTOR.message_types_by_name['GetUserProfileResponse']
_UPDATEUSERPROFILEREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserProfileRequest']
_UPDATEUSERPROFILERESPONSE = DESCRIPTOR.message_types_by_name['UpdateUserProfileResponse']
_REVOKEAPIKEYRESPONSE_STATUS = _REVOKEAPIKEYRESPONSE.enum_types_by_name['Status']
GenerateApiKeyRequest = _reflection.GeneratedProtocolMessageType('GenerateApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEAPIKEYREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.GenerateApiKeyRequest)
  })
_sym_db.RegisterMessage(GenerateApiKeyRequest)

GenerateApiKeyResponse = _reflection.GeneratedProtocolMessageType('GenerateApiKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEAPIKEYRESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.GenerateApiKeyResponse)
  })
_sym_db.RegisterMessage(GenerateApiKeyResponse)

RevokeApiKeyRequest = _reflection.GeneratedProtocolMessageType('RevokeApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEAPIKEYREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.RevokeApiKeyRequest)
  })
_sym_db.RegisterMessage(RevokeApiKeyRequest)

RevokeApiKeyResponse = _reflection.GeneratedProtocolMessageType('RevokeApiKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEAPIKEYRESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.RevokeApiKeyResponse)
  })
_sym_db.RegisterMessage(RevokeApiKeyResponse)

ListApiKeyDetailsRequest = _reflection.GeneratedProtocolMessageType('ListApiKeyDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPIKEYDETAILSREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.ListApiKeyDetailsRequest)
  })
_sym_db.RegisterMessage(ListApiKeyDetailsRequest)

ListApiKeyDetailsResponse = _reflection.GeneratedProtocolMessageType('ListApiKeyDetailsResponse', (_message.Message,), {

  'EnvironmentToApiKeyDetailsEntry' : _reflection.GeneratedProtocolMessageType('EnvironmentToApiKeyDetailsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY,
    '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
    # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.ListApiKeyDetailsResponse.EnvironmentToApiKeyDetailsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTAPIKEYDETAILSRESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.ListApiKeyDetailsResponse)
  })
_sym_db.RegisterMessage(ListApiKeyDetailsResponse)
_sym_db.RegisterMessage(ListApiKeyDetailsResponse.EnvironmentToApiKeyDetailsEntry)

GetUserProfileRequest = _reflection.GeneratedProtocolMessageType('GetUserProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERPROFILEREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.GetUserProfileRequest)
  })
_sym_db.RegisterMessage(GetUserProfileRequest)

GetUserProfileResponse = _reflection.GeneratedProtocolMessageType('GetUserProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERPROFILERESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.GetUserProfileResponse)
  })
_sym_db.RegisterMessage(GetUserProfileResponse)

UpdateUserProfileRequest = _reflection.GeneratedProtocolMessageType('UpdateUserProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERPROFILEREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.UpdateUserProfileRequest)
  })
_sym_db.RegisterMessage(UpdateUserProfileRequest)

UpdateUserProfileResponse = _reflection.GeneratedProtocolMessageType('UpdateUserProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERPROFILERESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.UpdateUserProfileResponse)
  })
_sym_db.RegisterMessage(UpdateUserProfileResponse)

_USERSERVICE = DESCRIPTOR.services_by_name['UserService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.self_service.v1.apiP\001Z\211\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/user/v1;self_service_user_v1'
  _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY._options = None
  _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY._serialized_options = b'8\001'
  _GENERATEAPIKEYREQUEST._serialized_start=154
  _GENERATEAPIKEYREQUEST._serialized_end=233
  _GENERATEAPIKEYRESPONSE._serialized_start=235
  _GENERATEAPIKEYRESPONSE._serialized_end=276
  _REVOKEAPIKEYREQUEST._serialized_start=278
  _REVOKEAPIKEYREQUEST._serialized_end=340
  _REVOKEAPIKEYRESPONSE._serialized_start=343
  _REVOKEAPIKEYRESPONSE._serialized_end=485
  _REVOKEAPIKEYRESPONSE_STATUS._serialized_start=439
  _REVOKEAPIKEYRESPONSE_STATUS._serialized_end=485
  _LISTAPIKEYDETAILSREQUEST._serialized_start=487
  _LISTAPIKEYDETAILSREQUEST._serialized_end=513
  _LISTAPIKEYDETAILSRESPONSE._serialized_start=516
  _LISTAPIKEYDETAILSRESPONSE._serialized_end=778
  _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY._serialized_start=671
  _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY._serialized_end=778
  _GETUSERPROFILEREQUEST._serialized_start=780
  _GETUSERPROFILEREQUEST._serialized_end=803
  _GETUSERPROFILERESPONSE._serialized_start=805
  _GETUSERPROFILERESPONSE._serialized_end=891
  _UPDATEUSERPROFILEREQUEST._serialized_start=893
  _UPDATEUSERPROFILEREQUEST._serialized_end=981
  _UPDATEUSERPROFILERESPONSE._serialized_start=983
  _UPDATEUSERPROFILERESPONSE._serialized_end=1080
  _USERSERVICE._serialized_start=1083
  _USERSERVICE._serialized_end=1703
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/entities/entity_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.entities import entity_pb2 as qwak_dot_feature__store_dot_entities_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0qwak/feature_store/entities/entity_service.proto\x12\x1bqwak.feature.store.entities\x1a(qwak/feature_store/entities/entity.proto\"S\n\x13\x43reateEntityRequest\x12<\n\x0b\x65ntity_spec\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"f\n\x13UpdateEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\x12<\n\x0b\x65ntity_spec\x18\x02 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"K\n\x14UpdateEntityResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"K\n\x14\x43reateEntityResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\")\n\x14GetEntityByIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\"L\n\x15GetEntityByIdResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"-\n\x16GetEntityByNameRequest\x12\x13\n\x0b\x65ntity_name\x18\x01 \x01(\t\"N\n\x17GetEntityByNameResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"(\n\x13\x44\x65leteEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteEntityResponse\"\x15\n\x13ListEntitiesRequest\"M\n\x14ListEntitiesResponse\x12\x35\n\x08\x65ntities\x18\x01 \x03(\x0b\x32#.qwak.feature.store.entities.Entity2\xd9\x05\n\rEntityService\x12s\n\x0c\x43reateEntity\x12\x30.qwak.feature.store.entities.CreateEntityRequest\x1a\x31.qwak.feature.store.entities.CreateEntityResponse\x12s\n\x0cUpdateEntity\x12\x30.qwak.feature.store.entities.UpdateEntityRequest\x1a\x31.qwak.feature.store.entities.UpdateEntityResponse\x12s\n\x0c\x44\x65leteEntity\x12\x30.qwak.feature.store.entities.DeleteEntityRequest\x1a\x31.qwak.feature.store.entities.DeleteEntityResponse\x12v\n\rGetEntityById\x12\x31.qwak.feature.store.entities.GetEntityByIdRequest\x1a\x32.qwak.feature.store.entities.GetEntityByIdResponse\x12|\n\x0fGetEntityByName\x12\x33.qwak.feature.store.entities.GetEntityByNameRequest\x1a\x34.qwak.feature.store.entities.GetEntityByNameResponse\x12s\n\x0cListEntities\x12\x30.qwak.feature.store.entities.ListEntitiesRequest\x1a\x31.qwak.feature.store.entities.ListEntitiesResponseB]\n(com.qwak.ai.feature.store.management.apiP\x01Z/qwak/featurestore/entities;featurestoreentitiesb\x06proto3')



_CREATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['CreateEntityRequest']
_UPDATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['UpdateEntityRequest']
_UPDATEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['UpdateEntityResponse']
_CREATEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['CreateEntityResponse']
_GETENTITYBYIDREQUEST = DESCRIPTOR.message_types_by_name['GetEntityByIdRequest']
_GETENTITYBYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetEntityByIdResponse']
_GETENTITYBYNAMEREQUEST = DESCRIPTOR.message_types_by_name['GetEntityByNameRequest']
_GETENTITYBYNAMERESPONSE = DESCRIPTOR.message_types_by_name['GetEntityByNameResponse']
_DELETEENTITYREQUEST = DESCRIPTOR.message_types_by_name['DeleteEntityRequest']
_DELETEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['DeleteEntityResponse']
_LISTENTITIESREQUEST = DESCRIPTOR.message_types_by_name['ListEntitiesRequest']
_LISTENTITIESRESPONSE = DESCRIPTOR.message_types_by_name['ListEntitiesResponse']
CreateEntityRequest = _reflection.GeneratedProtocolMessageType('CreateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.CreateEntityRequest)
  })
_sym_db.RegisterMessage(CreateEntityRequest)

UpdateEntityRequest = _reflection.GeneratedProtocolMessageType('UpdateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.UpdateEntityRequest)
  })
_sym_db.RegisterMessage(UpdateEntityRequest)

UpdateEntityResponse = _reflection.GeneratedProtocolMessageType('UpdateEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.UpdateEntityResponse)
  })
_sym_db.RegisterMessage(UpdateEntityResponse)

CreateEntityResponse = _reflection.GeneratedProtocolMessageType('CreateEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.CreateEntityResponse)
  })
_sym_db.RegisterMessage(CreateEntityResponse)

GetEntityByIdRequest = _reflection.GeneratedProtocolMessageType('GetEntityByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYBYIDREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.GetEntityByIdRequest)
  })
_sym_db.RegisterMessage(GetEntityByIdRequest)

GetEntityByIdResponse = _reflection.GeneratedProtocolMessageType('GetEntityByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYBYIDRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.GetEntityByIdResponse)
  })
_sym_db.RegisterMessage(GetEntityByIdResponse)

GetEntityByNameRequest = _reflection.GeneratedProtocolMessageType('GetEntityByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYBYNAMEREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.GetEntityByNameRequest)
  })
_sym_db.RegisterMessage(GetEntityByNameRequest)

GetEntityByNameResponse = _reflection.GeneratedProtocolMessageType('GetEntityByNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYBYNAMERESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.GetEntityByNameResponse)
  })
_sym_db.RegisterMessage(GetEntityByNameResponse)

DeleteEntityRequest = _reflection.GeneratedProtocolMessageType('DeleteEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.DeleteEntityRequest)
  })
_sym_db.RegisterMessage(DeleteEntityRequest)

DeleteEntityResponse = _reflection.GeneratedProtocolMessageType('DeleteEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.DeleteEntityResponse)
  })
_sym_db.RegisterMessage(DeleteEntityResponse)

ListEntitiesRequest = _reflection.GeneratedProtocolMessageType('ListEntitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.ListEntitiesRequest)
  })
_sym_db.RegisterMessage(ListEntitiesRequest)

ListEntitiesResponse = _reflection.GeneratedProtocolMessageType('ListEntitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.ListEntitiesResponse)
  })
_sym_db.RegisterMessage(ListEntitiesResponse)

_ENTITYSERVICE = DESCRIPTOR.services_by_name['EntityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z/qwak/featurestore/entities;featurestoreentities'
  _CREATEENTITYREQUEST._serialized_start=123
  _CREATEENTITYREQUEST._serialized_end=206
  _UPDATEENTITYREQUEST._serialized_start=208
  _UPDATEENTITYREQUEST._serialized_end=310
  _UPDATEENTITYRESPONSE._serialized_start=312
  _UPDATEENTITYRESPONSE._serialized_end=387
  _CREATEENTITYRESPONSE._serialized_start=389
  _CREATEENTITYRESPONSE._serialized_end=464
  _GETENTITYBYIDREQUEST._serialized_start=466
  _GETENTITYBYIDREQUEST._serialized_end=507
  _GETENTITYBYIDRESPONSE._serialized_start=509
  _GETENTITYBYIDRESPONSE._serialized_end=585
  _GETENTITYBYNAMEREQUEST._serialized_start=587
  _GETENTITYBYNAMEREQUEST._serialized_end=632
  _GETENTITYBYNAMERESPONSE._serialized_start=634
  _GETENTITYBYNAMERESPONSE._serialized_end=712
  _DELETEENTITYREQUEST._serialized_start=714
  _DELETEENTITYREQUEST._serialized_end=754
  _DELETEENTITYRESPONSE._serialized_start=756
  _DELETEENTITYRESPONSE._serialized_end=778
  _LISTENTITIESREQUEST._serialized_start=780
  _LISTENTITIESREQUEST._serialized_end=801
  _LISTENTITIESRESPONSE._serialized_start=803
  _LISTENTITIESRESPONSE._serialized_end=880
  _ENTITYSERVICE._serialized_start=883
  _ENTITYSERVICE._serialized_end=1612
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

import shutil
from abc import ABC, abstractmethod
from pathlib import Path
from typing import Any, Callable, Optional, Tuple, Union

from qwak.inner.build_logic.interface.build_logger_interface import BuildLogger
from qwak.inner.build_logic.tools.ignore_files import load_patterns_from_ignore_file

_IGNORED_PATTERNS = [r"\..*", r"__pycache__"]
QWAK_IGNORE_FILE_NAME = ".qwakignore"


def get_ignore_pattern(
    src: str, main_dir: str, build_logger: BuildLogger
) -> Tuple[Callable[[Any, list[str]], set[str]], list[str]]:
    if (Path(src) / main_dir / QWAK_IGNORE_FILE_NAME).is_file():
        ignore_file_path = Path(src) / main_dir / QWAK_IGNORE_FILE_NAME
    else:
        ignore_file_path = Path(src) / QWAK_IGNORE_FILE_NAME

    ignored_patterns = (
        load_patterns_from_ignore_file(
            build_logger=build_logger, ignore_file_path=ignore_file_path
        )
        + _IGNORED_PATTERNS
    )

    return shutil.ignore_patterns(*ignored_patterns), ignored_patterns


class Strategy(ABC):
    def __init__(self, build_logger: BuildLogger):
        self.build_logger = build_logger

    @abstractmethod
    def fetch(
        self,
        src: Union[str, Path],
        dest: str,
        git_branch: str,
        git_credentials: str,
        model_id: str,
        build_id: str,
        custom_dependency_path: Optional[str],
    ) -> Optional[str]:
        pass



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ArtifactorySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_REGISTRY_PREFIX_FIELD_NUMBER: builtins.int
    INTERNAL_REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_DETAILS_FIELD_NUMBER: builtins.int
    container_registry_prefix: builtins.str
    internal_repository_name: builtins.str
    @property
    def authentication_details(self) -> global___ArtifactoryAuthenticationDetails: ...
    def __init__(
        self,
        *,
        container_registry_prefix: builtins.str = ...,
        internal_repository_name: builtins.str = ...,
        authentication_details: global___ArtifactoryAuthenticationDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_details", b"authentication_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_details", b"authentication_details", "container_registry_prefix", b"container_registry_prefix", "internal_repository_name", b"internal_repository_name"]) -> None: ...

global___ArtifactorySettings = ArtifactorySettings

class ArtifactoryAuthenticationDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    token: builtins.str
    username: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        username: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tenant_id", b"tenant_id", "token", b"token", "username", b"username"]) -> None: ...

global___ArtifactoryAuthenticationDetails = ArtifactoryAuthenticationDetails



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/alert_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.deployment import alert_pb2 as qwak_dot_deployment_dot_alert__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/deployment/alert_service.proto\x12\x1aqwak.deployment.management\x1a\x1bqwak/deployment/alert.proto\"`\n\x1dGetAlertsConfigurationRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\"W\n\x1eGetAlertsConfigurationResponse\x12\x35\n\x06\x61lerts\x18\x01 \x03(\x0b\x32%.qwak.deployment.management.AlertRule\"\xad\x01\n\x1f\x41pplyAlertsConfigurationRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x35\n\x06\x61lerts\x18\x03 \x03(\x0b\x32%.qwak.deployment.management.AlertRule\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\"\"\n ApplyAlertsConfigurationResponse\"<\n\"GetNotificationChannelsListRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"y\n#GetNotificationChannelsListResponse\x12R\n\x15notification_channels\x18\x01 \x03(\x0b\x32\x33.qwak.deployment.management.NotificationChannelSpec\"\x88\x01\n\x1f\x41pplyNotificationChannelRequest\x12M\n\x14notification_channel\x18\x01 \x01(\x0b\x32/.qwak.deployment.management.NotificationChannel\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\"\n ApplyNotificationChannelResponse\"[\n DeleteNotificationChannelRequest\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"#\n!DeleteNotificationChannelResponse\"B\n(GetNotificationChannelDetailsListRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"{\n)GetNotificationChannelDetailsListResponse\x12N\n\x15notification_channels\x18\x01 \x03(\x0b\x32/.qwak.deployment.management.NotificationChannel2\xc9\x07\n\x16\x41lertManagementService\x12\x8f\x01\n\x16GetAlertsConfiguration\x12\x39.qwak.deployment.management.GetAlertsConfigurationRequest\x1a:.qwak.deployment.management.GetAlertsConfigurationResponse\x12\x95\x01\n\x18\x41pplyAlertsConfiguration\x12;.qwak.deployment.management.ApplyAlertsConfigurationRequest\x1a<.qwak.deployment.management.ApplyAlertsConfigurationResponse\x12\x9e\x01\n\x1bGetNotificationChannelsList\x12>.qwak.deployment.management.GetNotificationChannelsListRequest\x1a?.qwak.deployment.management.GetNotificationChannelsListResponse\x12\x95\x01\n\x18\x41pplyNotificationChannel\x12;.qwak.deployment.management.ApplyNotificationChannelRequest\x1a<.qwak.deployment.management.ApplyNotificationChannelResponse\x12\x98\x01\n\x19\x44\x65leteNotificationChannel\x12<.qwak.deployment.management.DeleteNotificationChannelRequest\x1a=.qwak.deployment.management.DeleteNotificationChannelResponse\x12\xb0\x01\n!GetNotificationChannelDetailsList\x12\x44.qwak.deployment.management.GetNotificationChannelDetailsListRequest\x1a\x45.qwak.deployment.management.GetNotificationChannelDetailsListResponseB)\n%com.qwak.ai.management.deployment.apiP\x01\x62\x06proto3')



_GETALERTSCONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['GetAlertsConfigurationRequest']
_GETALERTSCONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetAlertsConfigurationResponse']
_APPLYALERTSCONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['ApplyAlertsConfigurationRequest']
_APPLYALERTSCONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['ApplyAlertsConfigurationResponse']
_GETNOTIFICATIONCHANNELSLISTREQUEST = DESCRIPTOR.message_types_by_name['GetNotificationChannelsListRequest']
_GETNOTIFICATIONCHANNELSLISTRESPONSE = DESCRIPTOR.message_types_by_name['GetNotificationChannelsListResponse']
_APPLYNOTIFICATIONCHANNELREQUEST = DESCRIPTOR.message_types_by_name['ApplyNotificationChannelRequest']
_APPLYNOTIFICATIONCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['ApplyNotificationChannelResponse']
_DELETENOTIFICATIONCHANNELREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotificationChannelRequest']
_DELETENOTIFICATIONCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['DeleteNotificationChannelResponse']
_GETNOTIFICATIONCHANNELDETAILSLISTREQUEST = DESCRIPTOR.message_types_by_name['GetNotificationChannelDetailsListRequest']
_GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE = DESCRIPTOR.message_types_by_name['GetNotificationChannelDetailsListResponse']
GetAlertsConfigurationRequest = _reflection.GeneratedProtocolMessageType('GetAlertsConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTSCONFIGURATIONREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetAlertsConfigurationRequest)
  })
_sym_db.RegisterMessage(GetAlertsConfigurationRequest)

GetAlertsConfigurationResponse = _reflection.GeneratedProtocolMessageType('GetAlertsConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTSCONFIGURATIONRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetAlertsConfigurationResponse)
  })
_sym_db.RegisterMessage(GetAlertsConfigurationResponse)

ApplyAlertsConfigurationRequest = _reflection.GeneratedProtocolMessageType('ApplyAlertsConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYALERTSCONFIGURATIONREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ApplyAlertsConfigurationRequest)
  })
_sym_db.RegisterMessage(ApplyAlertsConfigurationRequest)

ApplyAlertsConfigurationResponse = _reflection.GeneratedProtocolMessageType('ApplyAlertsConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYALERTSCONFIGURATIONRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ApplyAlertsConfigurationResponse)
  })
_sym_db.RegisterMessage(ApplyAlertsConfigurationResponse)

GetNotificationChannelsListRequest = _reflection.GeneratedProtocolMessageType('GetNotificationChannelsListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONCHANNELSLISTREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetNotificationChannelsListRequest)
  })
_sym_db.RegisterMessage(GetNotificationChannelsListRequest)

GetNotificationChannelsListResponse = _reflection.GeneratedProtocolMessageType('GetNotificationChannelsListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONCHANNELSLISTRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetNotificationChannelsListResponse)
  })
_sym_db.RegisterMessage(GetNotificationChannelsListResponse)

ApplyNotificationChannelRequest = _reflection.GeneratedProtocolMessageType('ApplyNotificationChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYNOTIFICATIONCHANNELREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ApplyNotificationChannelRequest)
  })
_sym_db.RegisterMessage(ApplyNotificationChannelRequest)

ApplyNotificationChannelResponse = _reflection.GeneratedProtocolMessageType('ApplyNotificationChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYNOTIFICATIONCHANNELRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ApplyNotificationChannelResponse)
  })
_sym_db.RegisterMessage(ApplyNotificationChannelResponse)

DeleteNotificationChannelRequest = _reflection.GeneratedProtocolMessageType('DeleteNotificationChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFICATIONCHANNELREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.DeleteNotificationChannelRequest)
  })
_sym_db.RegisterMessage(DeleteNotificationChannelRequest)

DeleteNotificationChannelResponse = _reflection.GeneratedProtocolMessageType('DeleteNotificationChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFICATIONCHANNELRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.DeleteNotificationChannelResponse)
  })
_sym_db.RegisterMessage(DeleteNotificationChannelResponse)

GetNotificationChannelDetailsListRequest = _reflection.GeneratedProtocolMessageType('GetNotificationChannelDetailsListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONCHANNELDETAILSLISTREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetNotificationChannelDetailsListRequest)
  })
_sym_db.RegisterMessage(GetNotificationChannelDetailsListRequest)

GetNotificationChannelDetailsListResponse = _reflection.GeneratedProtocolMessageType('GetNotificationChannelDetailsListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetNotificationChannelDetailsListResponse)
  })
_sym_db.RegisterMessage(GetNotificationChannelDetailsListResponse)

_ALERTMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['AlertManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001'
  _GETALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._options = None
  _GETALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _APPLYALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._options = None
  _APPLYALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _GETALERTSCONFIGURATIONREQUEST._serialized_start=96
  _GETALERTSCONFIGURATIONREQUEST._serialized_end=192
  _GETALERTSCONFIGURATIONRESPONSE._serialized_start=194
  _GETALERTSCONFIGURATIONRESPONSE._serialized_end=281
  _APPLYALERTSCONFIGURATIONREQUEST._serialized_start=284
  _APPLYALERTSCONFIGURATIONREQUEST._serialized_end=457
  _APPLYALERTSCONFIGURATIONRESPONSE._serialized_start=459
  _APPLYALERTSCONFIGURATIONRESPONSE._serialized_end=493
  _GETNOTIFICATIONCHANNELSLISTREQUEST._serialized_start=495
  _GETNOTIFICATIONCHANNELSLISTREQUEST._serialized_end=555
  _GETNOTIFICATIONCHANNELSLISTRESPONSE._serialized_start=557
  _GETNOTIFICATIONCHANNELSLISTRESPONSE._serialized_end=678
  _APPLYNOTIFICATIONCHANNELREQUEST._serialized_start=681
  _APPLYNOTIFICATIONCHANNELREQUEST._serialized_end=817
  _APPLYNOTIFICATIONCHANNELRESPONSE._serialized_start=819
  _APPLYNOTIFICATIONCHANNELRESPONSE._serialized_end=853
  _DELETENOTIFICATIONCHANNELREQUEST._serialized_start=855
  _DELETENOTIFICATIONCHANNELREQUEST._serialized_end=946
  _DELETENOTIFICATIONCHANNELRESPONSE._serialized_start=948
  _DELETENOTIFICATIONCHANNELRESPONSE._serialized_end=983
  _GETNOTIFICATIONCHANNELDETAILSLISTREQUEST._serialized_start=985
  _GETNOTIFICATIONCHANNELDETAILSLISTREQUEST._serialized_end=1051
  _GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE._serialized_start=1053
  _GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE._serialized_end=1176
  _ALERTMANAGEMENTSERVICE._serialized_start=1179
  _ALERTMANAGEMENTSERVICE._serialized_end=2148
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ClusterTemplate:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ClusterTemplateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ClusterTemplate.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SMALL: _ClusterTemplate.ValueType  # 0
    MEDIUM: _ClusterTemplate.ValueType  # 1
    LARGE: _ClusterTemplate.ValueType  # 2
    XLARGE: _ClusterTemplate.ValueType  # 3
    XXLARGE: _ClusterTemplate.ValueType  # 4
    XXXLARGE: _ClusterTemplate.ValueType  # 5
    NANO: _ClusterTemplate.ValueType  # 6

class ClusterTemplate(_ClusterTemplate, metaclass=_ClusterTemplateEnumTypeWrapper):
    """Templates for clusters the user may choose"""

SMALL: ClusterTemplate.ValueType  # 0
MEDIUM: ClusterTemplate.ValueType  # 1
LARGE: ClusterTemplate.ValueType  # 2
XLARGE: ClusterTemplate.ValueType  # 3
XXLARGE: ClusterTemplate.ValueType  # 4
XXXLARGE: ClusterTemplate.ValueType  # 5
NANO: ClusterTemplate.ValueType  # 6
global___ClusterTemplate = ClusterTemplate

class ExecutionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_CONFIGURATION_FIELD_NUMBER: builtins.int
    cluster_template: global___ClusterTemplate.ValueType
    @property
    def resource_configuration(self) -> global___ResourceConfiguration: ...
    def __init__(
        self,
        *,
        cluster_template: global___ClusterTemplate.ValueType = ...,
        resource_configuration: global___ResourceConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_template", b"cluster_template", "resource_configuration", b"resource_configuration", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_template", b"cluster_template", "resource_configuration", b"resource_configuration", "spec", b"spec"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["spec", b"spec"]) -> typing_extensions.Literal["cluster_template", "resource_configuration"] | None: ...

global___ExecutionSpec = ExecutionSpec

class StreamingExecutionSpec(google.protobuf.message.Message):
    """Represents the Execution Specification of a streaming FeatureSet"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_CLUSTER_TEMPLATE_FIELD_NUMBER: builtins.int
    ONLINE_RESOURCE_CONFIGURATION_FIELD_NUMBER: builtins.int
    OFFLINE_CLUSTER_TEMPLATE_FIELD_NUMBER: builtins.int
    OFFLINE_RESOURCE_CONFIGURATION_FIELD_NUMBER: builtins.int
    online_cluster_template: global___ClusterTemplate.ValueType
    @property
    def online_resource_configuration(self) -> global___ResourceConfiguration: ...
    offline_cluster_template: global___ClusterTemplate.ValueType
    @property
    def offline_resource_configuration(self) -> global___ResourceConfiguration: ...
    def __init__(
        self,
        *,
        online_cluster_template: global___ClusterTemplate.ValueType = ...,
        online_resource_configuration: global___ResourceConfiguration | None = ...,
        offline_cluster_template: global___ClusterTemplate.ValueType = ...,
        offline_resource_configuration: global___ResourceConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["offline_cluster_template", b"offline_cluster_template", "offline_resource_configuration", b"offline_resource_configuration", "offline_resource_spec", b"offline_resource_spec", "online_cluster_template", b"online_cluster_template", "online_resource_configuration", b"online_resource_configuration", "online_resource_spec", b"online_resource_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["offline_cluster_template", b"offline_cluster_template", "offline_resource_configuration", b"offline_resource_configuration", "offline_resource_spec", b"offline_resource_spec", "online_cluster_template", b"online_cluster_template", "online_resource_configuration", b"online_resource_configuration", "online_resource_spec", b"online_resource_spec"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["offline_resource_spec", b"offline_resource_spec"]) -> typing_extensions.Literal["offline_cluster_template", "offline_resource_configuration"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["online_resource_spec", b"online_resource_spec"]) -> typing_extensions.Literal["online_cluster_template", "online_resource_configuration"] | None: ...

global___StreamingExecutionSpec = StreamingExecutionSpec

class BackfillExecutionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_CONFIGURATION_FIELD_NUMBER: builtins.int
    cluster_template: global___ClusterTemplate.ValueType
    @property
    def resource_configuration(self) -> global___ResourceConfiguration: ...
    def __init__(
        self,
        *,
        cluster_template: global___ClusterTemplate.ValueType = ...,
        resource_configuration: global___ResourceConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill_resource_spec", b"backfill_resource_spec", "cluster_template", b"cluster_template", "resource_configuration", b"resource_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill_resource_spec", b"backfill_resource_spec", "cluster_template", b"cluster_template", "resource_configuration", b"resource_configuration"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["backfill_resource_spec", b"backfill_resource_spec"]) -> typing_extensions.Literal["cluster_template", "resource_configuration"] | None: ...

global___BackfillExecutionSpec = BackfillExecutionSpec

class ResourceConfiguration(google.protobuf.message.Message):
    """user-defined resource configuration, to be applied to a cluster where
    Dynamic Allocation is enabled
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRIVER_MEMORY_FIELD_NUMBER: builtins.int
    DRIVER_CORES_FIELD_NUMBER: builtins.int
    INITIAL_EXECUTORS_FIELD_NUMBER: builtins.int
    MIN_EXECUTORS_FIELD_NUMBER: builtins.int
    MAX_EXECUTORS_FIELD_NUMBER: builtins.int
    EXECUTOR_MEMORY_FIELD_NUMBER: builtins.int
    EXECUTOR_CORES_FIELD_NUMBER: builtins.int
    driver_memory: builtins.str
    """driver memory, corresponds to "spark.driver.memory" and has the same format"""
    driver_cores: builtins.int
    """driver cores, corresponds to "spark.driver.cores" """
    initial_executors: builtins.int
    """initial executor count, corresponds to "spark.dynamicAllocation.initialExecutors" """
    min_executors: builtins.int
    """min number of executors, corresponds to "spark.dynamicAllocation.minExecutors" """
    max_executors: builtins.int
    """max number of executors, corresponds to "spark.dynamicAllocation.maxExecutors" """
    executor_memory: builtins.str
    """executor memory, corresponds to (and has the same format of) "spark.executor.memory" """
    executor_cores: builtins.int
    """executor cores, corresponds to "spark.executor.cores" """
    def __init__(
        self,
        *,
        driver_memory: builtins.str = ...,
        driver_cores: builtins.int = ...,
        initial_executors: builtins.int = ...,
        min_executors: builtins.int = ...,
        max_executors: builtins.int = ...,
        executor_memory: builtins.str = ...,
        executor_cores: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_cores", b"driver_cores", "driver_memory", b"driver_memory", "executor_cores", b"executor_cores", "executor_memory", b"executor_memory", "initial_executors", b"initial_executors", "max_executors", b"max_executors", "min_executors", b"min_executors"]) -> None: ...

global___ResourceConfiguration = ResourceConfiguration
